--- dns/nsd/Makefile	Sat Jun  3 05:05:35 2006
+++ dns/nsd/Makefile	Wed Sep  6 14:48:07 2006
@@ -5,15 +5,8 @@
 # $FreeBSD: ports/dns/nsd/Makefile,v 1.28 2006/06/03 03:05:35 mnag Exp $
 #
 
-# To pre-select options in batch mode, run make like this:
-#
-#  make -DBATCH NSD_OPTIONS="ROOT_SERVER BIND8_STATS"
-#
-# the options are the same names as in the scripts/configure.nsd file.
-# NSD_OPTIONS can be set in /etc/make.conf also.
-
 PORTNAME=	nsd
-PORTVERSION=	2.3.5
+PORTVERSION=	3.0.1
 CATEGORIES=	dns ipv6
 MASTER_SITES=	http://www.nlnetlabs.nl/downloads/nsd/	\
 		ftp://ftp.rhnet.is/pub/nsd/
@@ -26,13 +19,14 @@
 NSDUSER?=	bind
 NSDDIR?=	${PREFIX}/etc/nsd
 NSDDBFILE?=	/var/db/nsd.database
+NSDIXFRFILE?=	/var/db/nsd.ixfr.db
 
 GNU_CONFIGURE=	yes
 CONFIGURE_ARGS=	--with-user=${NSDUSER} \
 		--with-configdir=${NSDDIR} \
 		--with-pidfile=/var/run/nsd.pid \
 		--with-dbfile=${NSDDBFILE} \
-		--with-libwrap
+		--with-difffile=${NSDIXFRFILE}
 CONFIGURE_TARGET=	--build=${MACHINE_ARCH}-portbld-freebsd${OSREL}
 
 SED_SCRIPT=	-e 's,%%NSDUSER%%,${NSDUSER},g' \
@@ -40,42 +34,78 @@
 		-e 's,%%PREFIX%%,${PREFIX},g' \
 		-e 's,%%RC_SUBR%%,${RC_SUBR},g'
 
-MAN8=	nsd.8 zonec.8 nsdc.8 nsd-notify.8 nsd-xfer.8
+MAN5=	nsd.conf.5
+MAN8=	nsd.8 nsdc.8 zonec.8 nsd-checkconf.8 nsd-notify.8 nsd-patch.8 \
+	nsd-xfer.8
+
+PORTDOCS=	CREDITS README RELNOTES REQUIREMENTS UPGRADING
+
+OPTIONS=	ROOT_SERVER	"Configure NSD as a root server" Off \
+		LARGEFILE	"Enable support for large files" On \
+		IPV6		"Enable IPv6 support" On \
+		DNSSEC		"Enable DNSSEC" On \
+		BIND8_STATS	"Enable BIND8 like NSTATS & XSTATS" Off \
+		CHECKING	"Enable internal runtime checks" Off \
+		TSIG		"Enable TSIG support" On \
+		NSEC3		"Enable NSEC3 support" Off \
+		NSID		"Enable NSID support" Off \
+		DOCFILES	"Enable PORTDOCS" On
 
-PORTDOCS=	README RELNOTES CREDITS DIFFERENCES REQUIREMENTS
+.include <bsd.port.pre.mk>
 
-SCRIPTS_ENV=	WRKDIRPREFIX="${WRKDIRPREFIX}" \
-		TOUCH="${TOUCH}" \
-		MKDIR="${MKDIR}" \
-		NSD_OPTIONS="${NSD_OPTIONS}"
+.if defined(WITHOUT_LARGEFILE)
+CONFIGURE_ARGS+=	--disable-largefile
+.endif
 
-pre-fetch:
-	@${SETENV} ${SCRIPTS_ENV} ${SH} ${SCRIPTDIR}/configure.nsd
+.if defined(WITH_ROOT_SERVER)
+CONFIGURE_ARGS+=	--enable-root-server
+.endif
 
-.if exists(${WRKDIRPREFIX}${.CURDIR}/Makefile.inc)
-.include "${WRKDIRPREFIX}${.CURDIR}/Makefile.inc"
+.if defined(WITHOUT_IPV6)
+CONFIGURE_ARGS+=	--disable-ipv6
 .endif
 
-.if defined(NOPORTDOCS)
-READMEDIR=no
-.else
+.if defined(WITHOUT_DNSSEC)
+CONFIGURE_ARGS+=	--disable-dnssec
+.endif
+
+.if defined(WITH_BIND8_STATS)
+CONFIGURE_ARGS+=	--enable-bind8-stats
+.endif
+
+.if defined(WITH_CHECKING)
+CONFIGURE_ARGS+=	--enable-checking
+.endif
+
+.if defined(WITHOUT_TSIG)
+CONFIGURE_ARGS+=	--disable-tsig
+.endif
+
+.if defined(WITH_NSEC3)
+CONFIGURE_ARGS+=	--enable-nsec3
+.endif
+
+.if defined(WITH_NSID)
+CONFIGURE_ARGS+=	--enable-nsid
+.endif
+
+.if defined(WITH_DOCFILES)
 READMEDIR=${PREFIX}/share/doc/nsd
+.else
+READMEDIR=no
 .endif
 
 post-install:
 	${SED} ${SED_SCRIPT} < ${FILESDIR}/nsd.sh.tmpl >${WRKDIR}/nsd.sh
-.if !defined(NOPORTDOCS)
+	${INSTALL_DATA} ${WRKSRC}/nsd.conf.sample \
+		${NSDDIR}/nsd.conf.sample
+	${INSTALL_SCRIPT} ${WRKDIR}/nsd.sh ${PREFIX}/etc/rc.d/
+.if defined(WITH_DOCFILES)
 	@${MKDIR} ${DOCSDIR}
 .for f in ${PORTDOCS}
-	${INSTALL_DATA} ${WRKSRC}/${f} ${DOCSDIR}
+	${INSTALL_DATA} ${WRKSRC}/doc/${f} ${DOCSDIR}/${f}
 .endfor
 .endif
-	${INSTALL_DATA} ${WRKSRC}/nsd.zones.sample \
-		${PREFIX}/etc/nsd/nsd.zones.sample
-	${INSTALL_SCRIPT} ${WRKDIR}/nsd.sh ${PREFIX}/etc/rc.d/
 	@${CAT} ${PKGMESSAGE}
 
-post-clean:
-	@${RM} -f ${WRKDIRPREFIX}${.CURDIR}/Makefile.inc
-
-.include <bsd.port.mk>
+.include <bsd.port.post.mk>
--- dns/nsd/distinfo	Sat Jun  3 05:05:35 2006
+++ dns/nsd/distinfo	Wed Sep  6 14:48:28 2006
@@ -1,3 +1,3 @@
-MD5 (nsd-2.3.5.tar.gz) = e9dfb18d544cd37c57b05a91384037e9
-SHA256 (nsd-2.3.5.tar.gz) = cd16d3bbce2be200fb9fdbde20753642fe4f318b16e15528e953038a787fc6e2
-SIZE (nsd-2.3.5.tar.gz) = 239147
+MD5 (nsd-3.0.1.tar.gz) = 32932bc73b73fa267b232088931f412a
+SHA256 (nsd-3.0.1.tar.gz) = b19a3de2e6ab8b3316a34005287ef3138fe2e46bbe3d625aa636feb4a2ebfed9
+SIZE (nsd-3.0.1.tar.gz) = 403190
--- dns/nsd/files/nsd.sh.tmpl	Thu Nov  4 14:09:07 2004
+++ dns/nsd/files/nsd.sh.tmpl	Wed Sep  6 11:05:12 2006
@@ -17,7 +17,7 @@
 
 prefix=%%PREFIX%%
 
-required_files=%%NSDDIR%%/nsd.zones
+required_files=%%NSDDIR%%/nsd.conf
 
 command=/usr/local/sbin/${name}
 pidfile=/var/run/${name}.pid
--- dns/nsd/pkg-plist	Mon Feb  7 22:51:13 2005
+++ dns/nsd/pkg-plist	Tue Sep  5 23:32:35 2006
@@ -1,10 +1,11 @@
 @comment $FreeBSD: ports/dns/nsd/pkg-plist,v 1.4 2005/02/07 21:51:13 edwin Exp $
 etc/rc.d/nsd.sh
-etc/nsd/nsd.zones.sample
-etc/nsd/nsdc.conf.sample
+etc/nsd/nsd.conf.sample
 sbin/nsd
 sbin/zonec
 sbin/nsdc
 sbin/nsd-notify
+sbin/nsd-checkconf
+sbin/nsd-patch
 sbin/nsd-xfer
 @dirrm etc/nsd
--- dns/nsd/scripts/configure.nsd	Fri May  6 13:50:25 2005
+++ dns/nsd/scripts/configure.nsd	Thu Jan  1 01:00:00 1970
@@ -1,86 +0,0 @@
-#!/bin/sh
-# $FreeBSD: ports/dns/nsd/scripts/configure.nsd,v 1.2 2005/05/06 11:50:25 novel Exp $
-
-if [ -f ${WRKDIRPREFIX}${CURDIR}/Makefile.inc ]; then
-	exit
-fi
-
-tempfile=`mktemp -t checklist`
-
-if [ "${NSD_OPTIONS}" ]; then
-	set ${NSD_OPTIONS}
-fi
-
-for i; do
-	eval status_$i=ON
-done
-
-if [ -z "${BATCH}" ]; then
-	/usr/bin/dialog --title "NSD configuration options" --clear \
-		--checklist "\n\
-Please select desired options:" -1 -1 16 \
-ROOT_SERVER	"Configure NSD as a root server" "$status_ROOT_SERVER" \
-NOIPv6		"Disable IPv6 support" "$status_NOIPv6" \
-NODNSSEC	"Disable DNSSEC" "$status_NODNSSEC" \
-NOAXFR		"Disable AXFR" "$status_NOAXFR" \
-BIND8_STATS	"Enable BIND8 like NSTATS & XSTATS" "$status_BIND8_STATS" \
-PLUGINS		"Enable plugin support" "$status_PLUGINS" \
-NOTSIG		"Disable TSIG support" "$status_NOTSIG" \
-MMAP		"Configure NSD to load the database using mmap(2)" "$status_MMAP" \
-2> $tempfile
-
-	retval=$?
-
-	if [ -s $tempfile ]; then
-		set `sed 's/"//g' $tempfile`
-	fi
-	rm -f $tempfile
-
-	case $retval in
-		0)	if [ -z "$*" ]; then
-				echo "Nothing selected"
-			fi
-			;;
-		1)	echo "Cancel pressed."
-			exit 1
-			;;
-	esac
-fi
-
-${MKDIR} ${WRKDIRPREFIX}${CURDIR}
-exec > ${WRKDIRPREFIX}${CURDIR}/Makefile.inc
-
-while [ "$1" ]; do
-	case $1 in
-		ROOT_SERVER)
-			echo "CONFIGURE_ARGS+=        --enable-root-server"
-			;;
-		NOIPv6)
-			echo "CONFIGURE_ARGS+=        --disable-ipv6"
-			;;
-		NODNSSEC)
-			echo "CONFIGURE_ARGS+=        --disable-dnssec"
-			;;
-		NOAXFR)
-			echo "CONFIGURE_ARGS+=        --disable-axfr"
-			;;
-		BIND8_STATS)
-			echo "CONFIGURE_ARGS+=        --enable-bind8-stats"
-			;;
-		PLUGINS)
-			echo "CONFIGURE_ARGS+=        --enable-plugins"
-			;;
-		NOTSIG)
-			echo "CONFIGURE_ARGS+=        --disable-tsig"
-			;;
-		MMAP)
-			echo "CONFIGURE_ARGS+=        --enable-mmap"
-			;;
-		*)
-			echo "Unknown option(s): $*" > /dev/stderr
-			rm -f ${WRKDIRPREFIX}${CURDIR}/Makefile.inc
-			exit 1
-			;;
-	esac
-	shift
-done
